@@ -766,6 +766,10 @@ class Hint(Expression):
     arg_types = {"expressions": True}
 
 
+class JoinHint(Expression):
+    arg_types = {"this": True, "expressions": True}
+
+
 class Identifier(Expression):
     arg_types = {"this": True, "quoted": False}
 
@@ -1857,7 +1861,8 @@ class DataType(Expression):
         IMAGE = auto()
         VARIANT = auto()
         OBJECT = auto()
-        UNKNOWN = auto()  # Sentinel value, useful for the optimizer
+        NULL = auto()
+        UNKNOWN = auto()  # Sentinel value, useful for type annotation
 
     @classmethod
     def build(cls, dtype, **kwargs):
@@ -3149,7 +3154,7 @@ def alias_(expression, alias, table=False, dialect=None, quoted=None, **opts):
     alias = to_identifier(alias, quoted=quoted)
     alias = TableAlias(this=alias) if table else alias
 
-    if "alias" in exp.arg_types:
+    if "alias" in exp.arg_types and not isinstance(exp, Window):
         exp = exp.copy()
         exp.set("alias", alias)
         return exp
